RegisterCluster class

Constructors

RegisterCluster(String key, String? name, int addr, int size, RegisterType registerType, Map<String, RegisterField> fields, {String? tag})

Properties

addr int
getter/setter pair
fields Map<String, RegisterField>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
key String
getter/setter pair
name String?
getter/setter pair
readData Uint16List?
getter/setter pair
registerType RegisterType
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
getter/setter pair
tag String?
getter/setter pair
writeData Uint16List?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(Uint16List data) → dynamic
toString() String
A string representation of this object.
inherited
write() Uint16List

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

instance(String key, Map<String, dynamic> json) RegisterCluster