RegisterField class abstract

Implementers

Constructors

RegisterField(String key, FieldType type, String? name, int offset, int size, {String? tag, List? selection})

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
getter/setter pair
name String?
getter/setter pair
offset int
getter/setter pair
readValue ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection List?
getter/setter pair
size int
getter/setter pair
tag String?
getter/setter pair
type FieldType
getter/setter pair
writeValue ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(Uint16List data) → dynamic
toString() String
A string representation of this object.
inherited
write(Uint16List data) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

instance(String key, Map<String, dynamic> json) RegisterField